summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmlinkedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmlinkedit.h')
-rw-r--r--kpovmodeler/pmlinkedit.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/kpovmodeler/pmlinkedit.h b/kpovmodeler/pmlinkedit.h
index 935d8940..7c0b7451 100644
--- a/kpovmodeler/pmlinkedit.h
+++ b/kpovmodeler/pmlinkedit.h
@@ -37,21 +37,21 @@ class PMLinkEdit : public TQWidget
TQ_OBJECT
public:
/**
* Creates a link edit widget with tqparent and name.
*
* Allows the selection of declares of type declareType.
*/
- PMLinkEdit( const TQString& declareType, TQWidget* tqparent, const char* name = 0 );
+ PMLinkEdit( const TQString& declareType, TQWidget* parent, const char* name = 0 );
/**
* Creates a link edit widget with tqparent and name.
*
* Allows the selection of declares of type declares.
*/
- PMLinkEdit( const TQStringList& declares, TQWidget* tqparent, const char* name = 0 );
+ PMLinkEdit( const TQStringList& declares, TQWidget* parent, const char* name = 0 );
/**
* Creates a link edit widget with tqparent and name.
*/
- PMLinkEdit( TQWidget* tqparent, const char* name = 0 );
+ PMLinkEdit( TQWidget* parent, const char* name = 0 );
/**
* Sets the displayed object and displays the link
@@ -37,21 +37,21 @@ class PMLinkEdit : public TQWidget
public:
/**
- * Creates a link edit widget with tqparent and name.
+ * Creates a link edit widget with parent and name.
*
* Allows the selection of declares of type declareType.
@@ -37,21 +37,21 @@ class PMLinkEdit : public TQWidget
/**
- * Creates a link edit widget with tqparent and name.
+ * Creates a link edit widget with parent and name.
*
* Allows the selection of declares of type declares.
@@ -37,21 +37,21 @@ class PMLinkEdit : public TQWidget
/**
- * Creates a link edit widget with tqparent and name.
+ * Creates a link edit widget with parent and name.
*/